@@ -3,20 +3,23 @@ from __future__ import annotations
 
 from aiohttp import ClientResponse
 from typing import Any, List
+from urllib.parse import urlencode
+
+from systembridge.objects.hardware_sensor import HardwareSensor
 
 from .client import BridgeClient
 from .client_websocket import BridgeClientWebSocket
-from .objects.audio import Audio
+from .objects.audio import Audio, AudioDevice, AudioSettings
 from .objects.audio.put import AudioPutPayload, AudioPutResponse
 from .objects.base import BridgeBase
 from .objects.battery import Battery
 from .objects.bluetooth import Bluetooth
 from .objects.command.payload import CommandPayload
 from .objects.command.response import CommandResponse
-from .objects.cpu import Cpu
+from .objects.cpu import Cache, Cpu, CpuInner, CurrentSpeed, Temperature
 from .objects.display import DisplayBase
 from .objects.events import Event, EventBase
-from .objects.filesystem import Filesystem
+from .objects.filesystem import BlockDevices, DiskLayout, Filesystem, FsSize
 from .objects.filesystem.file import FilesystemFile
 from .objects.graphics import Graphics
 from .objects.information import Information
@@ -26,7 +29,7 @@ from .objects.memory import Memory
 from .objects.network import Network
 from .objects.open.payload import OpenPayload
 from .objects.os import Os
-from .objects.processes import ProcessList, Processes
+from .objects.processes import Load, ProcessList, Processes
 from .objects.settings import Settings
 from .objects.settings.put import SettingsPutPayload
 from .objects.system import System
@@ -74,17 +77,6 @@ class Bridge(BridgeBase):
     def bluetooth(self) -> Bluetooth:
         return self._bluetooth
 
-    @property
-    def configuration_url(self) -> str:
-        """Get configuration url"""
-        url = f"{self.base_url}/app/settings?apiKey={self._api_key}"
-        if self.information is not None:
-            if self.information.apiPort is not None:
-                url += f"&apiPort={self.information.apiPort}"
-            if self.information.websocketPort is not None:
-                url += f"&wsPort={self.information.websocketPort}"
-        return url
-
     @property
     def cpu(self) -> Cpu:
         return self._cpu
@@ -326,16 +318,81 @@ class Bridge(BridgeBase):
                     name = event.name.replace("data-", "")
                     if name == "audio":
                         self._audio = Audio(event.data)
+                    if name == "audio-findCurrent":
+                        if self._audio is None:
+                            self._audio = Audio({"current": event.data})
+                        else:
+                            self._audio = Audio({**self._audio, "current": event.data})
+                    if name == "audio-getDevices":
+                        if self._audio is None:
+                            self._audio = Audio({"devices": event.data})
+                        else:
+                            self._audio = Audio({**self._audio, "devices": event.data})
                     elif name == "battery":
                         self._battery = Battery(event.data)
                     elif name == "bluetooth":
                         self._bluetooth = Bluetooth(event.data)
                     elif name == "cpu":
                         self._cpu = Cpu(event.data)
+                    elif name == "cpu-findCpuCache":
+                        if self._cpu is None:
+                            self._cpu = Cpu({"cache": event.data})
+                        else:
+                            self._cpu = Cpu({**self._cpu, "cache": event.data})
+                    elif name == "cpu-findCpu":
+                        if self._cpu is None:
+                            self._cpu = Cpu({"cpu": event.data})
+                        else:
+                            self._cpu = Cpu({**self._cpu, "cpu": event.data})
+                    elif name == "cpu-findCurrentSpeed":
+                        if self._cpu is None:
+                            self._cpu = Cpu({"currentSpeed": event.data})
+                        else:
+                            self._cpu = Cpu({**self._cpu, "currentSpeed": event.data})
+                    elif name == "cpu-findTemperature":
+                        if self._cpu is None:
+                            self._cpu = Cpu({"temperature": event.data})
+                        else:
+                            self._cpu = Cpu({**self._cpu, "temperature": event.data})
+                    elif name == "cpu-findHardwareSensors":
+                        if self._cpu is None:
+                            self._cpu = Cpu({"hardwareSensors": event.data})
+                        else:
+                            self._cpu = Cpu(
+                                {**self._cpu, "hardwareSensors": event.data}
+                            )
                     elif name == "display":
                         self._display = DisplayBase(event.data)
                     elif name == "filesystem":
                         self._filesystem = Filesystem(event.data)
+                    elif name == "filesystem-findBlockDevices":
+                        if self._filesystem is None:
+                            self._filesystem = Filesystem({"blockDevices": event.data})
+                        else:
+                            self._filesystem = Filesystem(
+                                {**self._filesystem, "blockDevices": event.data}
+                            )
+                    elif name == "filesystem-findDisksLayout":
+                        if self._filesystem is None:
+                            self._filesystem = Filesystem({"diskLayout": event.data})
+                        else:
+                            self._filesystem = Filesystem(
+                                {**self._filesystem, "diskLayout": event.data}
+                            )
+                    elif name == "filesystem-findDisksIO":
+                        if self._filesystem is None:
+                            self._filesystem = Filesystem({"disksIO": event.data})
+                        else:
+                            self._filesystem = Filesystem(
+                                {**self._filesystem, "disksIO": event.data}
+                            )
+                    elif name == "filesystem-findSizes":
+                        if self._filesystem is None:
+                            self._filesystem = Filesystem({"fsSize": event.data})
+                        else:
+                            self._filesystem = Filesystem(
+                                {**self._filesystem, "fsSize": event.data}
+                            )
                     elif name == "graphics":
                         self._graphics = Graphics(event.data)
                     elif name == "information":
@@ -348,6 +405,13 @@ class Bridge(BridgeBase):
                         self._os = Os(event.data)
                     elif name == "processes":
                         self._processes = Processes(event.data)
+                    elif name == "processes-findCurrentLoad":
+                        if self._processes is None:
+                            self._processes = Processes({"load": event.data})
+                        else:
+                            self._processes = Processes(
+                                {**self._processes, "load": event.data}
+                            )
                     elif name == "settings":
                         self._settings = [Settings(setting) for setting in event.data]
                     elif name == "system":
@@ -355,3 +419,15 @@ class Bridge(BridgeBase):
                 await callback(event)
 
         await self._websocket_client.listen_for_messages(handle_message)
+
+    def get_configuration_url(self, include_api_key=False) -> str:
+        """Get configuration url"""
+        return f"""{self.base_url}/app/settings?{urlencode({
+            "apiKey": self._api_key if include_api_key is not False else "",
+            "apiPort": self.information.apiPort
+            if self.information is not None
+            else "",
+            "wsPort": self.information.websocketPort
+            if self.information is not None
+            else "",
+        })}"""
